Crate mool_macros_impl

Crate mool_macros_impl 

Internal derive implementation shared by Mool and framework wrappers.

This crate is public only so proc-macro crates can reuse one implementation. Application code should depend on mool, not this crate.

Modules

filterable
model
record
sql_enum
SqlEnum derive implementation.

Functions

default_mool_path
Default path used by wrapper crates that intentionally pass none.
runtime_path
Resolves the runtime path used in generated DB code.